@@ -11,6 +11,6 @@ class NoQueueError(Exception):
 
 
 class UnpickleError(Exception):
-    def __init__(self, message, raw_data):
-        super(UnpickleError, self).__init__(message)
+    def __init__(self, message, raw_data, inner_exception=None):
+        super(UnpickleError, self).__init__(message, inner_exception)
         self.raw_data = raw_data
